@@ -2,21 +2,21 @@
 
 # Copyright (c) 2009, Purdue University
 # All rights reserved.
-# 
+#
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
-# 
+#
 # Redistributions of source code must retain the above copyright notice, this
 # list of conditions and the following disclaimer.
 #
 # Redistributions in binary form must reproduce the above copyright notice, this
 # list of conditions and the following disclaimer in the documentation and/or
 # other materials provided with the distribution.
-# 
+#
 # Neither the name of the Purdue University nor the names of its contributors
 # may be used to endorse or promote products derived from this software without
 # specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 # AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 # IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
@@ -35,7 +35,7 @@ Connects to XML RPC server and runs arbitrary functions.
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.15'
+__version__ = '0.16'
 
 
 import os
@@ -65,6 +65,10 @@ def RunFunction(function, user_name, credfile=None, credstring=None,
   Outputs:
     return from function in core
   """
+  # if args is None:
+  #   args = []
+  # if kwargs is None:
+  #   kwargs = {}
   if( credfile is None ):
     credfile = os.path.expanduser('~/.dnscred')
   else:
@@ -96,16 +100,24 @@ def RunFunction(function, user_name, credfile=None, credstring=None,
     if( raise_errors ):
       raise xmlrpclib.Fault(1, '(%s) %s' % (core_return['log_uuid_string'],
                                             core_return['error']))
-    cli_common_lib.ServerError(core_return['error'],
-                               core_return['log_uuid_string'], 1)
+    if( core_return['error_class'] == 'InternalError' ):
+      cli_common_lib.ServerError(core_return['error'],
+                                 core_return['log_uuid_string'], 1)
+    elif( core_return['error_class'] == 'UserError' ):
+      cli_common_lib.UserError(core_return['error'], 1)
+    else:
+      cli_common_lib.UnknownError(
+          core_return['error_class'],
+          core_return['log_uuid_string'],
+          core_return['error'], 1)
 
   if( core_return == 'ERROR: Invalid Credentials' ):
-      if( not CheckCredentials(user_name, credfile, server_name,
+    if( not CheckCredentials(user_name, credfile, server_name,
                                password=password) ):
-        print "ERROR: Credential file not found, invalid credentials."
-        sys.exit(1)
+      print "ERROR: Credential file not found, invalid credentials."
+      sys.exit(1)
   elif( core_return['new_credential'] is not None and
-        core_return['new_credential'] != '' ):
+    core_return['new_credential'] != '' ):
     if( os.path.exists(credfile) ):
       credfile_handle = open(credfile, 'w')
       try:
@@ -178,8 +190,8 @@ def IsAuthenticated(user_name, credfile,
   server = xmlrpclib.ServerProxy(server_name, allow_none=True)
   authenticated = server.IsAuthenticated(user_name, credstring)
   if( type(authenticated) == dict and 'error' in authenticated ):
-      cli_common_lib.ServerError(authenticated['error'],
-                                 authenticated['log_uuid_string'], 1)
+    cli_common_lib.ServerError(authenticated['error'],
+                                authenticated['log_uuid_string'], 1)
   else:
     return authenticated
 
@@ -198,7 +210,7 @@ def CheckCredentials(username, credfile, server, password=None):
   if( not credfile ):
     self.DnsError('No credential file specified.', 1)
   got_credential = None
-  count = 0 
+  count = 0
   while( count < 3 ):
     valid = IsAuthenticated(username, credfile, server_name=server)
     if( valid ):
@@ -215,7 +227,7 @@ def CheckCredentials(username, credfile, server, password=None):
       got_credential = GetCredentials(username, password, credfile, server)
     except InvalidCredentials:
       if( password is None ):
-        count = count + 1 
+        count = count + 1
       else:
         print 'ERROR: Incorrect username/password.'
         sys.exit(1)
@@ -224,3 +236,17 @@ def CheckCredentials(username, credfile, server, password=None):
     sys.exit(1)
 
   return got_credential
+
+def CheckServerVersionMatch(server_name):
+  """Does a version check between this client and server
+
+  Inputs:
+    server_name: string name of server to check
+  """
+  server = xmlrpclib.ServerProxy(server_name, allow_none=True)
+  server_version =  server.GetVersion()
+  if( server_version != __version__ ):
+    print ('user_tools version %s mismatch with server version %s' % (
+               __version__, server_version))
+    sys.exit(1)
+    
